All Classes and Interfaces
Class
Description
Handler invoked when a REQUEST-phase breakpoint is hit.
Handler invoked when a RESPONSE-phase breakpoint is hit.
Handler invoked when a RESPONSE_STREAM or INBOUND_STREAM phase breakpoint is hit.
Deprecated.
instead use org.mockserver.client.initialize.PluginExpectationInitializer or org.mockserver.server.initialize.ExpectationInitializer
Convenience re-exports of LLM model-class static factories so that
users can write a single import:
Builder for multi-turn LLM conversation mocks with optional per-session isolation.
Builder for LLM provider failover/retry test scenarios.
Fluent builder for creating LLM mock expectations.
If the MockServer is started using the Maven Plugin a initializationClass property can be specified to initialize expectations, when the MockServer starts.
Sub-builder for configuring a single turn within an LLM conversation mock.