- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Handler invoked when a RESPONSE-phase breakpoint is hit. The paused request
and response are passed to the handler; the return value is the response
that will be written to the downstream client (continue or modify).
-
Method Summary
Modifier and TypeMethodDescriptionorg.mockserver.model.HttpResponsehandle(org.mockserver.model.HttpRequest httpRequest, org.mockserver.model.HttpResponse httpResponse) Handle a paused response at the RESPONSE breakpoint phase.
-
Method Details
-
handle
org.mockserver.model.HttpResponse handle(org.mockserver.model.HttpRequest httpRequest, org.mockserver.model.HttpResponse httpResponse) Handle a paused response at the RESPONSE breakpoint phase.- Parameters:
httpRequest- the original requesthttpResponse- the upstream response that was paused- Returns:
- the response to write to the downstream client
-